# Appa Run
Appa Run is a package used to load and execute impact model produced by the Appa Build package. It is part of the Appa LCA framework.

Appa LCA (**A**utomatable, **P**ortable and **Pa**rametric **L**ife **C**ycle **A**ssessment) framework was developed to ease the usage of screening LCA in any workflow or software, in the intention of easing ecodesign initiatives.
It intends to bring the best of the LCA method, which is versatile, holistic and flexible, and of _ad hoc_ impact assessment tools, which are easy to use and integrate.
It relies on the production and usage of impact models, which can be seen as standalone, parametric and modular LCA templates that operate at the impact level, i.e. after application of the LCIA methods.  

Documentation of Appa LCA is hosted here: https://appalca.github.io/ 
